import { ReactEditor } from '../../plugin/react-editor';
/**
 * Based loosely on:
 *
 * https://github.com/facebook/draft-js/blob/master/src/component/handlers/composition/DOMObserver.js
 * https://github.com/ProseMirror/prosemirror-view/blob/master/src/domobserver.js
 *
 * But is an analysis mainly for `backspace` and `enter` as we handle
 * compositions as a single operation.
 *
 * @param editor
 */
export declare class AndroidInputManager {
    private editor;
    /**
     * A MutationObserver that flushes to the method `flush`
     */
    private readonly observer;
    private rootEl?;
    /**
     * Object that keeps track of the most recent state
     */
    private lastPath?;
    private lastDiff?;
    private lastRange?;
    private lastDomNode?;
    constructor(editor: ReactEditor);
    onDidMount: () => void;
    onDidUpdate: () => void;
    /**
     * Connect the MutationObserver to a specific editor root element
     */
    connect: () => void;
    onWillUnmount: () => void;
    disconnect: () => void;
    onRender: () => void;
    private clearDiff;
    /**
     * Clear the `last` properties related to an action only
     */
    private clearAction;
    /**
     * Apply the last `diff`
     *
     * We don't want to apply the `diff` at the time it is created because we
     * may be in a composition. There are a few things that trigger the applying
     * of the saved diff. Sometimes on its own and sometimes immediately before
     * doing something else with the Editor.
     *
     * - `onCompositionEnd` event
     * - `onSelect` event only when the user has moved into a different node
     * - The user hits `enter`
     * - The user hits `backspace` and removes an inline node
     * - The user hits `backspace` and merges two blocks
     */
    private applyDiff;
    /**
     * Handle `enter` that splits block
     */
    private splitBlock;
    /**
     * Handle `backspace` that merges blocks
     */
    private mergeBlock;
    /**
     * The requestId used to the save selection
     */
    private onSelectTimeoutId;
    private bufferedMutations;
    private startActionFrameId;
    private isFlushing;
    /**
     * Mark the beginning of an action. The action happens when the
     * `requestAnimationFrame` expires.
     *
     * If `onKeyDown` is called again, it pushes the `action` to a new
     * `requestAnimationFrame` and cancels the old one.
     */
    private startAction;
    /**
     * Handle MutationObserver flush
     *
     * @param mutations
     */
    flush: (mutations: MutationRecord[]) => void;
    /**
     * Handle a `requestAnimationFrame` long batch of mutations.
     *
     * @param mutations
     */
    private flushAction;
    /**
     * Takes a DOM Node and resolves it against Slate's Document.
     *
     * Saves the changes to `last.diff` which can be applied later using
     * `applyDiff()`
     *
     * @param domNode
     */
    private resolveDOMNode;
    /**
     * handle `onCompositionStart`
     */
    onCompositionStart: () => void;
    /**
     * handle `onCompositionEnd`
     */
    onCompositionEnd: () => void;
    /**
     * Handle `onSelect` event
     *
     * Save the selection after a `requestAnimationFrame`
     *
     * - If we're not in the middle of flushing mutations
     * - and cancel save if a mutation runs before the `requestAnimationFrame`
     */
    onSelect: () => void;
}
export default AndroidInputManager;
//# sourceMappingURL=android-input-manager.d.ts.map